<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ku_IQ" sourcelanguage="en_US">
<context>
    <name>AlbumDefaultPage</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="35"/>
        <source>Add Songs</source>
        <translation>ئەسەرەت بارەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="43"/>
        <source>Open Folders</source>
        <translation>پەتەن بارەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="59"/>
        <source>Drag music files here or</source>
        <translation>مۆسیقىی پەپەرەت بەرەوە یا</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="63"/>
        <source> scan the Music directory</source>
        <translation>مۆسیقىی پەپەرەت بەرەوە</translation>
    </message>
</context>
<context>
    <name>AlbumGridDelegate</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumGridDelegate.qml" line="116"/>
        <source>1 song</source>
        <translation>1 ئەسەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumGridDelegate.qml" line="116"/>
        <source>%1 songs</source>
        <translation>%1 ئەسەر</translation>
    </message>
</context>
<context>
    <name>AlbumListDelegate</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListDelegate.qml" line="107"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="33"/>
        <source>Album</source>
        <translation>ئەلبوم</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="38"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="43"/>
        <source>Tracks</source>
        <translation>تراك</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="48"/>
        <source>Date added</source>
        <translation>تاریخ چاپ</translation>
    </message>
</context>
<context>
    <name>AlbumMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="20"/>
        <source>View details</source>
        <translation>ئەمەزەت نەزەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="28"/>
        <source>Play all</source>
        <translation>ھەممی دەرەوە دەرەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="37"/>
        <source>Add to</source>
        <translation>بەرەوە دەرەوە</translation>
    </message>
</context>
<context>
    <name>AlbumSublist</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="36"/>
        <source>Title</source>
        <translation>Sernivîs</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="41"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="46"/>
        <source>Duration</source>
        <translation>مۆسەفەت</translation>
    </message>
</context>
<context>
    <name>AlbumSublistDelegate</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistDelegate.qml" line="147"/>
        <source>My Favorites</source>
        <translation>ئەمەزەت نەزەر</translation>
    </message>
</context>
<context>
    <name>AlbumSublistView</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="55"/>
        <source>Title</source>
        <translation>Sernivîs</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="60"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="66"/>
        <source>Duration</source>
        <translation>مۆسەفەت</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumView.qml" line="54"/>
        <source>Albums</source>
        <translation>ئەلبومە</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumView.qml" line="55"/>
        <source>%1 albums - %2 songs</source>
        <translation>%1 ئەلبوم - %2 ئەسەر</translation>
    </message>
</context>
<context>
    <name>AllMusicDefaultPage</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="42"/>
        <source>Add Songs</source>
        <translation>ئەسەرەت بارەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="50"/>
        <source>Open Folders</source>
        <translation>پەتەن بارەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="65"/>
        <source>Drag music files here or</source>
        <translation>مۆسیقىی پەپەرەت بەرەوە یا</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="99"/>
        <source>Your favorite songs will be displayed here</source>
        <translation>ئەمەزەت نەزەر ئەسەرەت بەرەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="111"/>
        <source>Click “</source>
        <translation>کلیک کەرەوە “</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="122"/>
        <source>” to add a song to My Favorites</source>
        <translation>” یەک ئەسەر بەرەوە یەمەزەت نەزەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="157"/>
        <source>No songs yet. Click “</source>
        <translation>ئەسەرەت نەدەرەوە. کلیک کەرەوە “</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="168"/>
        <source>” to add songs to the playlist</source>
        <translation>” یەک ئەسەر بەرەوە یەک لیست</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="69"/>
        <source> scan the Music directory</source>
        <translation>مۆسیقىی پەپەرەت بەرەوە</translation>
    </message>
</context>
<context>
    <name>AllMusicList</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="17"/>
        <source>All Songs</source>
        <translation>ھەممی ئەسەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="30"/>
        <source>1 song</source>
        <translation>ھەممی ئەسەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="30"/>
        <source>%1 songs</source>
        <translation>%1 ئەسەر</translation>
    </message>
</context>
<context>
    <name>AllMusicListDelegate</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListDelegate.qml" line="212"/>
        <source>My Favorites</source>
        <translation>نەرخەن بەرە</translation>
    </message>
</context>
<context>
    <name>AllMusicListView</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="38"/>
        <source>Title</source>
        <translation>Sernivîs</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="44"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="49"/>
        <source>Album</source>
        <translation>آلبوم</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="54"/>
        <source>Duration</source>
        <translation>مەرکەت</translation>
    </message>
</context>
<context>
    <name>ArtistDefaultPage</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="36"/>
        <source>Add Songs</source>
        <translation>ئەرە بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="44"/>
        <source>Open Folders</source>
        <translation>پەتەن بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="60"/>
        <source>Drag music files here or</source>
        <translation>ئەرە بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="64"/>
        <source> scan the Music directory</source>
        <translation>یا مەدیا کاتەری بەرە</translation>
    </message>
</context>
<context>
    <name>ArtistGridDelegate</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistGridDelegate.qml" line="149"/>
        <source>1 song</source>
        <translation>1 ئەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistGridDelegate.qml" line="149"/>
        <source>%1 songs</source>
        <translation>%1 ئەرە</translation>
    </message>
</context>
<context>
    <name>ArtistMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="18"/>
        <source>View details</source>
        <translation>تەنە بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="26"/>
        <source>Play all</source>
        <translation>ھەممە بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="35"/>
        <source>Add to</source>
        <translation>بەرە</translation>
    </message>
</context>
<context>
    <name>ArtistSublistDelegate</name>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistDelegate.qml" line="102"/>
        <source>My Favorites</source>
        <translation>نەرخەن بەرە</translation>
    </message>
</context>
<context>
    <name>ArtistSublistView</name>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="59"/>
        <source>Title</source>
        <translation>Sernivîs</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="65"/>
        <source>Album</source>
        <translation>آلبوم</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="70"/>
        <source>Duration</source>
        <translation>مەرکەت</translation>
    </message>
</context>
<context>
    <name>ArtistView</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistView.qml" line="54"/>
        <source>Artists</source>
        <translation>ئەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistView.qml" line="55"/>
        <source>%1 artists - %2 songs</source>
        <translation>%1 ئەرە - %2 ئەرە</translation>
    </message>
</context>
<context>
    <name>CDRemovedDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/CDRemovedDialog.qml" line="32"/>
        <source>The CD has been removed</source>
        <translation>دیسکەک ئەوە بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CDRemovedDialog.qml" line="36"/>
        <source>Cancel</source>
        <translation>پاشگەزبوونەوە</translation>
    </message>
</context>
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="36"/>
        <source>Please choose your action</source>
        <translation>ئەوە بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="50"/>
        <source>Minimize to system tray</source>
        <translation>Li sêniya pergalê biçûk bike</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="62"/>
        <source>Exit</source>
        <translation>Derkeve</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="73"/>
        <source>Do not ask again</source>
        <translation>بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="90"/>
        <source>Cancel</source>
        <translation>پاشگەزبوونەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="98"/>
        <source>Confirm</source>
        <translation>Bipejirîne</translation>
    </message>
</context>
<context>
    <name>CurrentPlayList</name>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="97"/>
        <source>Play queue</source>
        <translation>بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="114"/>
        <source>1 song</source>
        <translation>1 ئەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="114"/>
        <source>%1 songs</source>
        <translation>%1 ئەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="128"/>
        <source>Empty</source>
        <translation>خالی</translation>
    </message>
</context>
<context>
    <name>CurrentPlayListDelegate</name>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayListDelegate.qml" line="123"/>
        <source>My Favorites</source>
        <translation>نەرخەن بەرە</translation>
    </message>
</context>
<context>
    <name>CustomPlaylistModel</name>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="23"/>
        <source>My Favorites</source>
        <translation>دیسکەک بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="80"/>
        <source>CD playlist</source>
        <translation>دیسکەک</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="86"/>
        <source>CD</source>
        <translation>ئەوە بەرە</translation>
    </message>
</context>
<context>
    <name>DeleteLocalDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="34"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>ئەوە بەرە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="36"/>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="45"/>
        <source>The song files contained will also be deleted</source>
        <translation>ئەرەقەت پەیوەندە ئەنجامەنە ئەرەقەتەکە هەم چاک بکەن</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="53"/>
        <source>Delete</source>
        <translation>Jê bibe</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="65"/>
        <source>Cancel</source>
        <translation>پاشگەزبوونەوە</translation>
    </message>
</context>
<context>
    <name>DeleteSonglistDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="41"/>
        <source>Are you sure you want to remove %1?</source>
        <translation>ئەرەقەت %1 ڕەنگەنە چاک بکەن؟</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="43"/>
        <source>Are you sure you want to remove the selected %1 songs?</source>
        <translation>ئەرەقەتەکە %1 ڕەنگەنە چاک بکەن؟</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="45"/>
        <source>Are you sure you want to delete this playlist?</source>
        <translation>ئەرەقەتە لیستەکە چاک بکەن؟</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="55"/>
        <source>Remove</source>
        <translation>چاک بکە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="55"/>
        <source>Delete</source>
        <translation>Jê bibe</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="70"/>
        <source>Cancel</source>
        <translation>پاشگەزبوونەوە</translation>
    </message>
</context>
<context>
    <name>EqualizerDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="14"/>
        <source>Custom</source>
        <translation>Taybet</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="15"/>
        <source>Monophony</source>
        <translation>مۆنۆفونی</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="16"/>
        <source>Classical</source>
        <translation>کلاسیک</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="17"/>
        <source>Club</source>
        <translation>کلوب</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="18"/>
        <source>Dance</source>
        <translation>دەنس</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="19"/>
        <source>Full Bass</source>
        <translation>بەس کامە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="20"/>
        <source>Full Bass and Treble</source>
        <translation>بەس و تربل کامە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="21"/>
        <source>Full Treble</source>
        <translation>تربل کامە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="22"/>
        <source>Headphones</source>
        <translation>ئەرەقەتە ھەدفون</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="23"/>
        <source>Hall</source>
        <translation>هال</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="24"/>
        <source>Live</source>
        <translation>لایڤ</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="25"/>
        <source>Party</source>
        <translation>پارتی</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="26"/>
        <source>Pop</source>
        <translation>پۆپ</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="27"/>
        <source>Reggae</source>
        <translation>رەگە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="28"/>
        <source>Rock</source>
        <translation>رۆک</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="29"/>
        <source>Ska</source>
        <translation>سکا</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="30"/>
        <source>Soft</source>
        <translation>سۆف</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="31"/>
        <source>Soft Rock</source>
        <translation>سۆف رۆک</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="32"/>
        <source>Techno</source>
        <translation>تېکنو</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="106"/>
        <source>Equalizer</source>
        <translation>ئەکیوازەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="182"/>
        <source>Save</source>
        <translation>بەرکەوتو</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="205"/>
        <source>Reset</source>
        <translation>بەرکەوتو کردن</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="314"/>
        <source>Preamplifier</source>
        <translation>پریەمپلیفایەر</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/FileDialog.qml" line="15"/>
        <source>All Music</source>
        <translation>ھەموو موزیک</translation>
    </message>
</context>
<context>
    <name>ImportFailedDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/ImportFailedDialog.qml" line="32"/>
        <source>Import failed, no valid music file found</source>
        <translation>ئەمپورت کردنە چەکە، فایل موزیکی ھەموو چەکە یاندە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/ImportFailedDialog.qml" line="36"/>
        <source>OK</source>
        <translation>Baş e</translation>
    </message>
</context>
<context>
    <name>ImportMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="25"/>
        <source>Play queue</source>
        <translation>پڵەی کوێ</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="40"/>
        <source>My favorites</source>
        <translation>Bijareyên min</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="49"/>
        <source>Create new playlist</source>
        <translation>ئەوەتە نووسەن پلەیلەست</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="52"/>
        <source>New playlist</source>
        <translation>Lîsteya lêdanê ya nû</translation>
    </message>
</context>
<context>
    <name>LyricPage</name>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="133"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="141"/>
        <source>Album</source>
        <translation>آلبوم</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="179"/>
        <source>No lyrics found</source>
        <translation>لێریک نەدۆزرا</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="189"/>
        <source>Please put the lyric file (same name as the song) and the song file in the same folder</source>
        <translation>لەوە بەرەو کەشەوەتە (ئەدەمی ئەوەتە ناوی سۆنگە) و سۆنگ فایل بەرەو فولدری هەمان بکەرەو</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="188"/>
        <source>Music</source>
        <translation>Mûzîk</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="203"/>
        <source>Play/Pause</source>
        <translation>Lêde/Bisekinîne</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="207"/>
        <source>Previous</source>
        <translation>Paşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="218"/>
        <source>Next</source>
        <translation>Pêşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="229"/>
        <source>Exit</source>
        <translation>Derkeve</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="343"/>
        <source>Already added to the playlist</source>
        <translation>ئەوەتە دەوەتە پلەیلەست بەرەو کەشەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="346"/>
        <source>Added to &quot;%1&quot;</source>
        <translation>بەرەو &quot;%1&quot; دەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="349"/>
        <source>Removed from &quot;My Favorites&quot;</source>
        <translation>بەرەو &quot;ئیم فاڤوریت&quot; ئەوەتە کەشەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="352"/>
        <source>A disc is connected</source>
        <translation>دیسکێک دەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="368"/>
        <source>My Favorites</source>
        <translation>ئیم فاڤوریت</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="390"/>
        <source>All Songs</source>
        <translation>هەموو سۆنگە</translation>
    </message>
</context>
<context>
    <name>MulitSelectMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="19"/>
        <source>Add to</source>
        <translation>بەرەو کەشەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="28"/>
        <source>Remove from playlist</source>
        <translation>Ji lîsteya lêdanê rake</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="28"/>
        <source>Remove from play queue</source>
        <translation>بەرەو پلای کووا کەشەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="35"/>
        <source>Delete from local disk</source>
        <translation>Ji dîska xwecihî bibe</translation>
    </message>
</context>
<context>
    <name>MusicBaselistview</name>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="36"/>
        <source>Library</source>
        <translation>کیتابخانە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="40"/>
        <source>Albums</source>
        <translation>آلبومەکان</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="41"/>
        <source>Artists</source>
        <translation>نەتەندرووەکان</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="42"/>
        <source>All Songs</source>
        <translation>هەموو سۆنگە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="47"/>
        <source>Playlists</source>
        <translation>پلەیلەستەکان</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="64"/>
        <source>Create playlist</source>
        <translation>پلەیلەستێک نووسەن</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="66"/>
        <source>New playlist</source>
        <translation>Lîsteya lêdanê ya nû</translation>
    </message>
</context>
<context>
    <name>MusicContentWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/MusicContentWindow.qml" line="22"/>
        <source>My Favorites</source>
        <translation>ئیم فاڤوریت</translation>
    </message>
</context>
<context>
    <name>MusicInfoDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="71"/>
        <source>Title</source>
        <translation>Sernivîs</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="80"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="86"/>
        <source>Album</source>
        <translation>آلبوم</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="95"/>
        <source>Type</source>
        <translation>نەتەن</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="101"/>
        <source>Size</source>
        <translation>هەولەو</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="107"/>
        <source>Duration</source>
        <translation>دەرەک</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="114"/>
        <source>Path</source>
        <translation>Rê</translation>
    </message>
</context>
<context>
    <name>MusicMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="24"/>
        <source>Pause</source>
        <translation>Bisekine</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="24"/>
        <source>Play</source>
        <translation>Lê Bide</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="44"/>
        <source>Add to</source>
        <translation>بەرەو کەشەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="52"/>
        <source>Open in file manager</source>
        <translation>بەرەو فایل مانیجر ئەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="62"/>
        <source>Remove from playlist</source>
        <translation>Ji lîsteya lêdanê rake</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="62"/>
        <source>Remove from play queue</source>
        <translation>بەرەو پلای کووا کەشەوەتە</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="72"/>
        <source>Delete from local disk</source>
        <translation>Ji dîska xwecihî bibe</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="79"/>
        <source>Encoding</source>
        <translation>Kodkirin</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="104"/>
        <source>Song info</source>
        <translation>Agahiya stranê</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/music-player/main.cpp" line="131"/>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>مۆسیقی ھەڵبەندەکەری مۆسیقییە بەشدارکردنەری بەھەمی و سادەیە</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="133"/>
        <source>Music</source>
        <translation>Mûzîk</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="143"/>
        <source>Unknown album</source>
        <translation>Album nayê zanîn</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="143"/>
        <source>Unknown artist</source>
        <translation>Hunermend nayê zanîn</translation>
    </message>
</context>
<context>
    <name>SearchResultDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="27"/>
        <source>Songs</source>
        <translation>سۆنگەکان</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="39"/>
        <source>Artists</source>
        <translation>نەتەندرووەکان</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="50"/>
        <source>Albums</source>
        <translation>آلبومەکان</translation>
    </message>
</context>
<context>
    <name>SearchResultWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="55"/>
        <source>No search results</source>
        <translation>هیچ نتایجی نیست</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="95"/>
        <source>Search Results</source>
        <translation>نتایج جویش</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="100"/>
        <source>%1 albums - %2 songs</source>
        <translation>&apos;%1 نووس - %2 شانس&apos;</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
        <source>1 album - 1 song</source>
        <translation>1 نووس - 1 شانس</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
        <source>%1 album - %2 songs</source>
        <translation>&apos;%1 نووس - %2 شانس&apos;</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="120"/>
        <source>Music</source>
        <translation>Mûzîk</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="128"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="124"/>
        <source>Album</source>
        <translation>نووس</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="30"/>
        <source>Basic</source>
        <translation>Bingehîn</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="34"/>
        <source>Play</source>
        <translation>Lê Bide</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="42"/>
        <source>Autoplay</source>
        <translation>Jixweberî lê de</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="53"/>
        <source>Remember playback position on exit</source>
        <translation>نیزەتەوە پەروەردەکەری پلەیەوە لە کۆتا</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="66"/>
        <source>Enable fade in/out</source>
        <translation>بەکارهێنەری چەکەوە/چەکەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="78"/>
        <source>Close Main Window</source>
        <translation>Paceya Bingehîn Bigire</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="91"/>
        <source>Minimize to system tray</source>
        <translation>Li sêniya pergalê biçûk bike</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="98"/>
        <source>Exit</source>
        <translation>دەرچوون</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="105"/>
        <source>Ask me always</source>
        <translation>هەر دووە بەکارهێنەری بەکارهێنەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="137"/>
        <source>Shortcuts</source>
        <translation>Kurtebirî</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="158"/>
        <source>Play/Pause</source>
        <translation>Lêde/Bisekinîne</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="201"/>
        <source>Previous</source>
        <translation>Paşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="245"/>
        <source>Next</source>
        <translation>Pêşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="290"/>
        <source>Volume up</source>
        <translation>Deng rake</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="335"/>
        <source>Volume down</source>
        <translation>Deng dîne</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="379"/>
        <source>Favorite</source>
        <translation>Bijare</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="501"/>
        <source>Cancel</source>
        <translation>پاشگەزبوونەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="534"/>
        <source>Replace</source>
        <translation>بەکارهێنەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="490"/>
        <source>This shortcut key conflicts with [%1], click Replace to make this shortcut key take effect immediately</source>
        <translation>چەکەوە کۆتایی هەڵەکەری [%1] دەکرێت، بەکارهێنەری بەکارهێنەر بۆیە کۆتایی دەکرێت</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="55"/>
        <source>Play</source>
        <translation>Lê Bide</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="56"/>
        <source>Songs</source>
        <translation>شانس</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="57"/>
        <source>Playlists</source>
        <translation>لیستەکان</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="58"/>
        <source>Settings</source>
        <translation>Mîheng</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="65"/>
        <source>Play/Pause</source>
        <translation>Lêde/Bisekinîne</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="66"/>
        <source>Previous</source>
        <translation>Paşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="67"/>
        <source>Next</source>
        <translation>Pêşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="68"/>
        <source>Volume Up</source>
        <translation>کۆلەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="69"/>
        <source>Volume Down</source>
        <translation>کۆلەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="70"/>
        <source>Mute</source>
        <translation>Bêdeng</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="73"/>
        <source>Favorite</source>
        <translation>Bijare</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="74"/>
        <source>Unfavorite</source>
        <translation>بەکارهێنەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="75"/>
        <source>Song info</source>
        <translation>Agahiya stranê</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="78"/>
        <source>New playlist</source>
        <translation>Lîsteya lêdanê ya nû</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="79"/>
        <source>Add music</source>
        <translation>موسيقىە دەدەن</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="80"/>
        <source>Rename playlist</source>
        <translation>ناوی لیستە دەدەن</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="81"/>
        <source>Remove from playlist</source>
        <translation>Ji lîsteya lêdanê rake</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="84"/>
        <source>Help</source>
        <translation>کارکەری</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="85"/>
        <source>Display shortcuts</source>
        <translation>چەکەوەکان دەدەن</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="../src/music-player/allItems/Shortcuts.qml" line="51"/>
        <source>New playlist</source>
        <translation>Lîsteya lêdanê ya nû</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/Shortcuts.qml" line="120"/>
        <source>My Favorites</source>
        <translation>بەکارهێنەریم</translation>
    </message>
</context>
<context>
    <name>SidebarMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="22"/>
        <source>Play</source>
        <translation>Lê Bide</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="29"/>
        <source>Add songs</source>
        <translation>شانس دەدەن</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="38"/>
        <source>Rename</source>
        <translation>Dîsa nav lê bide</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="52"/>
        <source>Delete</source>
        <translation>Jê bibe</translation>
    </message>
</context>
<context>
    <name>SortMenu</name>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="29"/>
        <source>CD playlist</source>
        <translation>لیستەی دیسک</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="33"/>
        <source>Custom</source>
        <translation>Taybet</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="34"/>
        <source>Date added</source>
        <translation>تاریخ ھەڵبەستن</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="37"/>
        <source>Album</source>
        <translation>نووس</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="36"/>
        <source>Artist</source>
        <translation>Hunermend</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="35"/>
        <source>Title</source>
        <translation>Sernivîs</translation>
    </message>
</context>
<context>
    <name>SublistTitleButton</name>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="54"/>
        <source>1 song</source>
        <translation>1 شانس</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="54"/>
        <source>%1 songs</source>
        <translation>&apos;%1 شانس&apos;</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="64"/>
        <source>Play All</source>
        <translation>Hemû Lê de</translation>
    </message>
</context>
<context>
    <name>ToolButtonItem</name>
    <message>
        <location filename="../src/music-player/allItems/ToolButtonItem.qml" line="59"/>
        <source>Play All</source>
        <translation>Hemû Lê de</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Sequential play</source>
        <translation>پلەیەوە لە بەرەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>List loop</source>
        <translation>لیستەی چەکەوە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Single loop</source>
        <translation>پلەیەوە یەکەن</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Shuffle</source>
        <translation>Li hev bide</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="207"/>
        <source>Unfavorite</source>
        <translation>نەرەنە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="207"/>
        <source>Favorite</source>
        <translation>Bijare</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="220"/>
        <source>My Favorites</source>
        <translation>نەرەنەیم</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="238"/>
        <source>Previous</source>
        <translation>Paşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="259"/>
        <source>Play/Pause</source>
        <translation>Lêde/Bisekinîne</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="280"/>
        <source>Next</source>
        <translation>Pêşve</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="389"/>
        <source>Lyrics</source>
        <translation>Peyvên stranê</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="438"/>
        <source>Play Queue</source>
        <translation>تۆرەنە پلەی</translation>
    </message>
</context>
<context>
    <name>WindowTitlebar</name>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="56"/>
        <source>Add playlist</source>
        <translation>بەڕێی پەلەستە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="58"/>
        <source>New playlist</source>
        <translation>Lîsteya lêdanê ya nû</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="63"/>
        <source>Add music</source>
        <translation>بەڕێی مۆسیقی</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="71"/>
        <source>Equalizer</source>
        <translation>بەشدارکردنەر</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="82"/>
        <source>Settings</source>
        <translation>Mîheng</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="96"/>
        <source>Music</source>
        <translation>Mûzîk</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="98"/>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>مۆسیقی ھەڵبەندەکەری مۆسیقییە بەشدارکردنەری بەھەمی و سادەیە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="99"/>
        <source>Version:</source>
        <translation>وێرەن:</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="213"/>
        <source>Previous page</source>
        <translation>پەڕەی ھەڵبەندەکە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="229"/>
        <source>Next page</source>
        <translation>پەڕەی کەسیلەکە</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="239"/>
        <source>Search</source>
        <translation>Lê bigere</translation>
    </message>
</context>
</TS>